@@ -123,21 +123,18 @@ async def get_order_status(self, order_id: str, session: aiohttp.ClientSession):
 async def close_orders(self, order_ids: List[str], session: aiohttp.ClientSession):
     try:
         logging.info(f"CLOSING ORDERS: {order_ids}")
-        str_ids = json.dumps(order_ids)
-        query_str = get_cancel_multiple_orders_query(str_ids=str_ids)
-        payload = {"query": query_str, "variables": {}}
-        response = await self.request("POST", "graphql", session, payload)
+        if order_ids:
+            str_ids = json.dumps(order_ids)
+            query_str = get_cancel_multiple_orders_query(str_ids=str_ids)
+            payload = {"query": query_str, "variables": {}}
+            response = await self.request("POST", "graphql", session, payload)
+            logging.debug(response)
+            if 'errors' in response:
+                return None
 
-        for order in order_ids:
-            status = await self.get_order_status(order_id=order, session=session)
-            while status == "open":
-                await self.close_order_by_id(order_id=order, session=session)
-                status = await self.get_order_status(
-                    order_id=order, session=session
-                )
-
-            logging.info(f"ORDER {order} has correctly been closed: {status}")
-        return response
+            return response
+        else:
+            return None
     except Exception as err:
         logging.debug(err)
         raise Exception(
